@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,8 +34,8 @@ KCupsPrinter::KCupsPrinter(const QString &printer, bool isClass) :
 KCupsPrinter::KCupsPrinter(const QVariantHash &arguments) :
     m_arguments(arguments)
 {
-    m_printer = arguments[KCUPS_PRINTER_NAME].toString();
-    m_isClass = arguments[KCUPS_PRINTER_TYPE].toInt() & CUPS_PRINTER_CLASS;
+    m_printer = arguments[QLatin1String(KCUPS_PRINTER_NAME)].toString();
+    m_isClass = arguments[QLatin1String(KCUPS_PRINTER_TYPE)].toInt() & CUPS_PRINTER_CLASS;
 }
 
 QString KCupsPrinter::name() const
@@ -50,115 +50,116 @@ bool KCupsPrinter::isClass() const
 
 bool KCupsPrinter::isDefault() const
 {
-    return m_arguments[KCUPS_PRINTER_TYPE].toUInt() & CUPS_PRINTER_DEFAULT;
+    return m_arguments[QLatin1String(KCUPS_PRINTER_TYPE)].toUInt() & CUPS_PRINTER_DEFAULT;
 }
 
 bool KCupsPrinter::isShared() const
 {
-    return m_arguments[KCUPS_PRINTER_IS_SHARED].toBool();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_IS_SHARED)].toBool();
 }
 
 bool KCupsPrinter::isAcceptingJobs() const
 {
-    return m_arguments[KCUPS_PRINTER_IS_ACCEPTING_JOBS].toBool();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_IS_ACCEPTING_JOBS)].toBool();
 }
 
 cups_ptype_e KCupsPrinter::type() const
 {
-    return static_cast<cups_ptype_e>(m_arguments[KCUPS_PRINTER_TYPE].toUInt());
+    return static_cast<cups_ptype_e>(m_arguments[QLatin1String(KCUPS_PRINTER_TYPE)].toUInt());
 }
 
 QString KCupsPrinter::location() const
 {
-    return m_arguments[KCUPS_PRINTER_LOCATION].toString();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_LOCATION)].toString();
 }
 
 QString KCupsPrinter::info() const
 {
-    if (m_arguments[KCUPS_PRINTER_INFO].toString().isEmpty()) {
+    const QString printerInfo = m_arguments[QLatin1String(KCUPS_PRINTER_INFO)].toString();
+    if (printerInfo.isEmpty()) {
         return name();
     }
-    return m_arguments[KCUPS_PRINTER_INFO].toString();
+    return printerInfo;
 }
 
 QString KCupsPrinter::makeAndModel() const
 {
-    return m_arguments[KCUPS_PRINTER_MAKE_AND_MODEL].toString();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_MAKE_AND_MODEL)].toString();
 }
 
 QStringList KCupsPrinter::commands() const
 {
-    return m_arguments[KCUPS_PRINTER_COMMANDS].toStringList();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_COMMANDS)].toStringList();
 }
 
 QStringList KCupsPrinter::memberNames() const
 {
-    return m_arguments[KCUPS_MEMBER_NAMES].toStringList();
+    return m_arguments[QLatin1String(KCUPS_MEMBER_NAMES)].toStringList();
 }
 
 QString KCupsPrinter::deviceUri() const
 {
-    return m_arguments[KCUPS_DEVICE_URI].toString();
+    return m_arguments[QLatin1String(KCUPS_DEVICE_URI)].toString();
 }
 
 QStringList KCupsPrinter::errorPolicy() const
 {
-    return m_arguments[KCUPS_PRINTER_ERROR_POLICY].toStringList();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_ERROR_POLICY)].toStringList();
 }
 
 QStringList KCupsPrinter::errorPolicySupported() const
 {
-    return m_arguments[KCUPS_PRINTER_ERROR_POLICY_SUPPORTED].toStringList();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_ERROR_POLICY_SUPPORTED)].toStringList();
 }
 
 QStringList KCupsPrinter::opPolicy() const
 {
-    return m_arguments[KCUPS_PRINTER_OP_POLICY].toStringList();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_OP_POLICY)].toStringList();
 }
 
 QStringList KCupsPrinter::opPolicySupported() const
 {
-    return m_arguments[KCUPS_PRINTER_OP_POLICY_SUPPORTED].toStringList();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_OP_POLICY_SUPPORTED)].toStringList();
 }
 
 QStringList KCupsPrinter::jobSheetsDefault() const
 {
-    return m_arguments[KCUPS_JOB_SHEETS_DEFAULT].toStringList();
+    return m_arguments[QLatin1String(KCUPS_JOB_SHEETS_DEFAULT)].toStringList();
 }
 
 QStringList KCupsPrinter::jobSheetsSupported() const
 {
-    return m_arguments[KCUPS_JOB_SHEETS_SUPPORTED].toStringList();
+    return m_arguments[QLatin1String(KCUPS_JOB_SHEETS_SUPPORTED)].toStringList();
 }
 
 QStringList KCupsPrinter::requestingUserNameAllowed() const
 {
-    return m_arguments[KCUPS_REQUESTING_USER_NAME_ALLOWED].toStringList();
+    return m_arguments[QLatin1String(KCUPS_REQUESTING_USER_NAME_ALLOWED)].toStringList();
 }
 
 QStringList KCupsPrinter::requestingUserNameDenied() const
 {
-    return m_arguments[KCUPS_REQUESTING_USER_NAME_DENIED].toStringList();
+    return m_arguments[QLatin1String(KCUPS_REQUESTING_USER_NAME_DENIED)].toStringList();
 }
 
 QString KCupsPrinter::uriSupported() const
 {
-    return m_arguments[KCUPS_PRINTER_URI_SUPPORTED].toString();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_URI_SUPPORTED)].toString();
 }
 
 KCupsPrinter::Status KCupsPrinter::state() const
 {
-    return static_cast<Status>(m_arguments[KCUPS_PRINTER_STATE].toUInt());
+    return static_cast<Status>(m_arguments[QLatin1String(KCUPS_PRINTER_STATE)].toUInt());
 }
 
 QString KCupsPrinter::stateMsg() const
 {
-    return m_arguments[KCUPS_PRINTER_STATE_MESSAGE].toString();
+    return m_arguments[QLatin1String(KCUPS_PRINTER_STATE_MESSAGE)].toString();
 }
 
 int KCupsPrinter::markerChangeTime() const
 {
-    return m_arguments[KCUPS_MARKER_CHANGE_TIME].toInt();
+    return m_arguments[QLatin1String(KCUPS_MARKER_CHANGE_TIME)].toInt();
 }
 
 QVariant KCupsPrinter::argument(const QString &name) const
@@ -186,10 +187,10 @@ QString KCupsPrinter::iconName(cups_ptype_e type)
     // TODO get the ppd or something to get the real printer icon
     if (!(type & CUPS_PRINTER_COLOR)) {
         // If the printer is not color it is probably a laser one
-        return "printer-laser";
+        return QStringLiteral("printer-laser");
     } else if (type & CUPS_PRINTER_SCANNER) {
-        return "scanner";
+        return QStringLiteral("scanner");
     } else {
-        return "printer";
+        return QStringLiteral("printer");
     }
 }
