@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2012 by Daniel Nicoletti                           *
+ *   Copyright (C) 2010-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,31 +22,16 @@
 
 #include "NewPrinterNotification.h"
 
-#include <QTimer>
-
-#include <KPluginFactory>
-
-K_PLUGIN_FACTORY(PrintDFactory, registerPlugin<PrintManagerKded>();)
-
 PrintManagerKded::PrintManagerKded(QObject *parent, const QVariantList &args) :
-    KDEDModule(parent),
-    m_newPrinterNotification(0)
+    KDEDModule(parent)
 {
     Q_UNUSED(args)
 
-    QTimer::singleShot(0, this, SLOT(loadThread()));
+    new NewPrinterNotification(this);
 }
 
 PrintManagerKded::~PrintManagerKded()
 {
-    if (m_newPrinterNotification) {
-        m_newPrinterNotification->deleteLater();
-    }
 }
 
-void PrintManagerKded::loadThread()
-{
-    m_newPrinterNotification = new NewPrinterNotification;
-}
-
-#include "PrintManagerKded.moc"
+#include "moc_PrintManagerKded.cpp"
